*** Pesquisa Covid-19 - WAVE 1 ***

use "P:\UFG\Pesquisas\Covid-19\COPEI_Covid_W1(2).dta", clear

* Sociodemograficas*

recode gender (1=1 Homem) (else=0 Outros), gen(homem)
label variable homem "Homem"

gen educa = edubinned
label var educa "Escolaridade"
labe define educa 1 "Fundamental" 2 "Médio" 3 "Superior"
label values educa educa

recode age (2/6=.) (16/24=1) (25/34=2) (35/44=3) (45/54=4) /// 
	(55/max=5), gen(idade)
label variable idade "Idade"
label define idade 1 "18 a 24" 2 "25 a 34" 3 "35 a 44" /// 
	4 "45 a 55" 5 "55 ou mais"
label values idade idade

recode religion (1=1 Cat󬩣a) (2/3=2 Evangélica) ///
	(else=3 Outras), gen(religiao2)
label var religiao "Religião"

* Covid *

gen preocupa = worried
label var preocupa "Preocupação com a Covid-19"
label define preocupa 1 "Nada" 2 "Pouco" 3 "Bastante" 4 "Muito"
label values preocupa preocupa

gen medidas = multidao + promatriz_pro4serious + transporte + ///
	escolas + comercio + quarentena	
label var medidas "Medidas"

gen infot = matrizc17 + matrizc18 + matrizc10 ///
	+ matrizc13 + matrizc22 + matrizc21	/// 
	+ matrizc16 + matrizc31 + matrizc12 ///
	+ matrizc34 + matrizc14 + matrizc32 ///
	+ matrizc33 + matrizc23 + matrizc11	

* Partido preferido *

recode partypref (1=1 PT) (8=2 Bozo) (2/7=3 Outros) ///
	(else=4 Nenhum), gen(partpref2)
label var partpref2 "Partido preferido"	

* Mídia *

ren mediahab1_11 record
ren mediahab1_12 jn

label var record "Jornal da Record"
label var jn "Jornal Nacional"

/* Normalizar */

su preocupa, meanonly
gen zpreocupa = (preocupa - r(min))/(r(max) - r(min))
label var zpreocupa "Preocupação com a Covid-19"

su polcand, meanonly
gen zatencao  = (polcand  - r(min))/(r(max) - r(min))
label var zatencao "Atenção política"

su medidas, meanonly
gen zmedidas  = (medidas  - r(min))/(r(max) - r(min))
label var zmedidas "Medidas"

su infot, meanonly
gen zinfot  = (infot - r(min))/(r(max) - r(min))
label var zinfot "Conhecimento sobre a Covid-19"

/* Exposição seletiva */

eststo clear

eststo mod1: reg jn ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg [pweight = peso_fim]
	
eststo mod2: reg record ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg [pweight = peso_fim]

esttab, wide label unstack se(2) b(a2) scalars(F p r2 r2_a) ///
	title(Determinantes da exposição seletiva) 				///
	nonumbers addnote("Fonte: Pesquisa Covid-19") compress 	
		
/* Pós-estimação */

** Jornal Nacional ** 

eststo clear

reg jn ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg [pweight = peso_fim]
	
* Normalidae dos resíduos* 

predict r, resid
swilk r 

* Multicolinearidade *

vif

* Heterocedasticidade *

reg jn ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg 
	
estat imtest
estat hettest	

* Teste para viés da variável omitida *	

reg jn ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg

linktest 

** Jornal da Record ** 

eststo clear

reg record ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg [pweight = peso_fim]
	
* Normalidae dos resíduos* 

predict re, resid
swilk re 

* Multicolinearidade *

vif

* Heterocedasticidade *

reg record ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg 
	
estat imtest
estat hettest	

* Teste para viés da variável omitida *	

reg record ib(2).partpref2 ///
	zatencao zpreocupa zinfot zmedidas /// 
	homem ib(5).idade ib(3).educa ib(2).religiao2 ib(3).reg

linktest 
